from django.template.loader import render_to_string
from django.utils.translation import ugettext

from django_pusher.push import pusher
from notification import backends


class PusherBackend(backends.BaseBackend):
    spam_sensitivity = 1
    
    channel_name_fmt = "private-notices@%(recipient)s"
    
    def deliver(self, recipient, sender, notice_type, extra_context):
        channel_name = self.channel_name_fmt % {"recipient": recipient.username}
        event_name = notice_type.label
        
        context = self.default_context()
        context.update({
            "recipient": recipient,
            "sender": sender,
            "notice": ugettext(notice_type.display),
        })
        context.update(extra_context)
        
        messages = self.get_formatted_messages(("short.txt", "notice.html"), notice_type.label, context)
        
        title = render_to_string("notification/realtime/title.html", {"message": messages["short.txt"]}, context)
        html = render_to_string("notification/realtime/body.html", {"message": messages["notice.html"]}, context)
        
        pusher[channel_name].trigger(event_name, {
            "title": title,
            "html": html,
        })
    
    @staticmethod
    def authenticate(request, channel):
        if request.user.is_authenticated():
            if channel == PusherBackend.channel_name_fmt % {"recipient": request.user.username}:
                return True
        return False
